<?php
$hostname = 'https://cetakrapor.smkbpm.sch.id';
$dataFolder = 'data/';
$outputFolder = './'; // Folder untuk output HTML
$templateFile = __DIR__ . '/anonymous24.php';

$limitPerRun = 500;

ini_set('max_execution_time', 0); // Unlimited
ini_set('memory_limit', '2048M'); // Besarin aja

$template = file_get_contents($templateFile);
$allFiles = glob($dataFolder . '*.txt');
$totalFiles = count($allFiles);

$urls = [];
$linkArray = [];

for ($startIndex = 0; $startIndex < $totalFiles; $startIndex += $limitPerRun) {
    $batchFiles = array_slice($allFiles, $startIndex, $limitPerRun);

    foreach ($batchFiles as $file) {
        $slug = basename($file, '.txt');
        $lines = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
        if (count($lines) < 2) continue;

        $title = str_replace("Title: ", "", $lines[0]);
        $description = str_replace("Description: ", "", $lines[1]);

        $internalLinks = '';
        $canonical = "$hostname/$slug.html";

        $content = str_replace(
            ['{{brand}}', '{{title}}', '{{description}}', '{{internalLinks}}', '{{canonical}}'],
            [$slug, $title, $description, $internalLinks, $canonical],
            $template
        );

        file_put_contents($outputFolder . "$slug.html", $content);
        $urls[] = $canonical;
        $linkArray[] = "<a href='$slug.html'>$title</a>";
    }

    echo "✅ Batch selesai: " . min($startIndex + $limitPerRun, $totalFiles) . " / $totalFiles file<br>";
    flush(); ob_flush();
}

// Update internal links setelah semua file dibuat
foreach ($allFiles as $file) {
    $slug = basename($file, '.txt');
    $htmlPath = $outputFolder . "$slug.html";
    if (!file_exists($htmlPath)) continue;

    $html = file_get_contents($htmlPath);
    $titleLine = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES)[0] ?? '';
    $title = str_replace("Title: ", "", $titleLine);
    $internalLinks = implode(" | ", array_diff($linkArray, ["<a href='$slug.html'>$title</a>"]));
    $html = str_replace("{{internalLinks}}", $internalLinks, $html);
    file_put_contents($htmlPath, $html);
}

// Sitemap
function createSitemap($urls, $outputFolder, $hostname) {
    $date = date('Y-m-d');
    $xml = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
    $xml .= "<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\">\n";
    foreach ($urls as $url) {
        $xml .= "  <url>\n";
        $xml .= "    <loc>$url</loc>\n";
        $xml .= "    <lastmod>$date</lastmod>\n";
        $xml .= "    <changefreq>daily</changefreq>\n";
        $xml .= "    <priority>1.0</priority>\n";
        $xml .= "  </url>\n";
    }
    $xml .= "</urlset>";
    file_put_contents($outputFolder . 'sitemap.xml', $xml);
}

// robots.txt
function createRobotsTxt($hostname, $outputFolder) {
    $robots = "User-agent: *\nAllow: /\nSitemap: $hostname/sitemap.xml";
    file_put_contents($outputFolder . 'robots.txt', $robots);
}

createSitemap($urls, $outputFolder, $hostname);
createRobotsTxt($hostname, $outputFolder);

echo "<br>🚀 Deploy selesai total $totalFiles file. Sitemap dan robots.txt dibuat.";
?>
